@@ -3,6 +3,8 @@
 #  E-mail: hwnorm@outlook.com               #
 #  Homepage: https://github.com/hwfan       #
 #############################################
+from urllib.parse import urlparse
+
 def format_size(value):
     units = ["B", "KB", "MB", "GB", "TB", "PB"]
     size = 1024.0
@@ -22,4 +24,7 @@ def judge_session(url):
     elif 'dropbox' in url:
         return 'DropBox'
     else:
-        return 'DirectLink'
\ No newline at end of file
+        return 'DirectLink'
+
+def judge_scheme(url):
+    return urlparse(url).scheme
\ No newline at end of file
